"use strict";
var __spreadArray = (this && this.__spreadArray) || function (to, from) {
    for (var i = 0, il = from.length, j = to.length; i < il; i++, j++)
        to[j] = from[i];
    return to;
};
Object.defineProperty(exports, "__esModule", { value: true });
var httpcode_1 = require("../src/httpcode");
var successCodeDataset = Object.values(httpcode_1.HTTP_CODE_SUCCESS).map(function (httpCode) { return [httpCode]; });
var informationCodeDataset = Object.values(httpcode_1.HTTP_CODE_INFORMATION).map(function (httpCode) { return [httpCode]; });
var redirectionCodeDataset = Object.values(httpcode_1.HTTP_CODE_REDIRECTION).map(function (httpCode) { return [httpCode]; });
var clientErrorCodeDataset = Object.values(httpcode_1.HTTP_CODE_CLIENT_ERROR).map(function (httpCode) { return [httpCode]; });
var serverErrorCodeDataset = Object.values(httpcode_1.HTTP_CODE_SERVER_ERROR).map(function (httpCode) { return [httpCode]; });
describe('http code information type guard', function () {
    test.each(informationCodeDataset)('should return true for information http code (%p)', function (httpCode) {
        expect(httpcode_1.isHttpCodeInformation(httpCode)).toBeTruthy();
    });
    test.each(__spreadArray(__spreadArray(__spreadArray(__spreadArray([], successCodeDataset), redirectionCodeDataset), clientErrorCodeDataset), serverErrorCodeDataset))('should return false for not information http code (%p)', function (httpCode) {
        expect(httpcode_1.isHttpCodeInformation(httpCode)).toBeFalsy();
    });
    test('should work with string', function () {
        expect(httpcode_1.isHttpCodeInformation('100')).toBeTruthy();
    });
});
describe('http code success type guard', function () {
    test.each(successCodeDataset)('should return true for success http code (%p)', function (httpCode) {
        expect(httpcode_1.isHttpCodeSuccess(httpCode)).toBeTruthy();
    });
    test.each(__spreadArray(__spreadArray(__spreadArray(__spreadArray([], informationCodeDataset), redirectionCodeDataset), clientErrorCodeDataset), serverErrorCodeDataset))('should return false for not success http code (%p)', function (httpCode) {
        expect(httpcode_1.isHttpCodeSuccess(httpCode)).toBeFalsy();
    });
    test('should work with string', function () {
        expect(httpcode_1.isHttpCodeSuccess('200')).toBeTruthy();
    });
});
describe('http code redirection type guard', function () {
    test.each(redirectionCodeDataset)('should return true for redirection code (%p)', function (httpCode) {
        expect(httpcode_1.isHttpCodeRedirection(httpCode)).toBeTruthy();
    });
    test.each(__spreadArray(__spreadArray(__spreadArray(__spreadArray([], informationCodeDataset), successCodeDataset), clientErrorCodeDataset), serverErrorCodeDataset))('should return false for not redirection http code (%p)', function (httpCode) {
        expect(httpcode_1.isHttpCodeRedirection(httpCode)).toBeFalsy();
    });
    test('should work with string', function () {
        expect(httpcode_1.isHttpCodeRedirection('300')).toBeTruthy();
    });
});
describe('http code client error type guard', function () {
    test.each(clientErrorCodeDataset)('should return true for client error http code (%p)', function (httpCode) {
        expect(httpcode_1.isHttpCodeClientError(httpCode)).toBeTruthy();
    });
    test.each(__spreadArray(__spreadArray(__spreadArray(__spreadArray([], informationCodeDataset), successCodeDataset), redirectionCodeDataset), serverErrorCodeDataset))('should return false for not client error http code (%p)', function (httpCode) {
        expect(httpcode_1.isHttpCodeClientError(httpCode)).toBeFalsy();
    });
    test('should work with string', function () {
        expect(httpcode_1.isHttpCodeClientError('400')).toBeTruthy();
    });
});
describe('http code server error type guard', function () {
    test.each(serverErrorCodeDataset)('should return true server error http code (%p)', function (httpCode) {
        expect(httpcode_1.isHttpCodeServerError(httpCode)).toBeTruthy();
    });
    test.each(__spreadArray(__spreadArray(__spreadArray(__spreadArray([], informationCodeDataset), successCodeDataset), redirectionCodeDataset), clientErrorCodeDataset))('should return false for not server error http code (%p)', function (httpCode) {
        expect(httpcode_1.isHttpCodeServerError(httpCode)).toBeFalsy();
    });
    test('should work with string', function () {
        expect(httpcode_1.isHttpCodeServerError('500')).toBeTruthy();
    });
});
describe('http code includes all type of http code', function () {
    test.each(__spreadArray(__spreadArray(__spreadArray(__spreadArray(__spreadArray([], informationCodeDataset), successCodeDataset), redirectionCodeDataset), clientErrorCodeDataset), serverErrorCodeDataset))('should be include in HTTP_CODE (%p)', function (httpCode) {
        var HttpCodeValues = Object.values(httpcode_1.HTTP_CODE);
        expect(HttpCodeValues.includes(httpCode)).toBeTruthy();
    });
    test('should work with string', function () {
        expect(httpcode_1.isHttpCodeInformation('100')).toBeTruthy();
    });
});
//# sourceMappingURL=httpcode.spec.js.map